#
# spec file for package ghc-unicode-collation
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name unicode-collation
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.1.3.6
Release:        150500.3.3.2
Summary:        Haskell implementation of the Unicode Collation Algorithm
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-th-lift-instances-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-unicode-transforms-devel
%endif

%description
This library provides a pure Haskell implementation of the Unicode Collation
Algorithm described at <http://www.unicode.org/reports/tr10/>. It is not as
fully-featured or as performant as 'text-icu', but it avoids a dependency on a
large C library. Locale-specific tailorings are also provided.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Wed Dec 20 2023 psimons@suse.com
- Update unicode-collation to version 0.1.3.6.
  [#]# 0.1.3.6
  * Update to build with GHC 9.8 (Laurent P. René de Cotret).
  [#]# 0.1.3.5
  * Allow text 2.1.
  [#]# 0.1.3.4
  * Allow base 4.18.
  [#]# 0.1.3.3
  * Allow base 4.17.  Closes #12.
* Thu May 19 2022 psimons@suse.com
- Update unicode-collation to version 0.1.3.2.
  [#]# 0.1.3.2
  * Allow text 2.0.
* Mon Nov 15 2021 psimons@suse.com
- Update unicode-collation to version 0.1.3.1.
  [#]# 0.1.3.1
  * Allow base 4.16 (so the library can compile with ghc 9.2).
  * Micro-optimization in normalize; update benchmarks.
* Thu May 13 2021 psimons@suse.com
- Add unicode-collation at version 0.1.3.
